@@ -252,6 +252,31 @@ class Finding:  # pylint: disable=too-many-public-methods
         """Title."""
         return self._data.get('Title')
 
+    @property
+    def description(self):
+        """Description."""
+        return self._data.get('Description')
+
+    @property
+    def remediation_recommendation_text(self):
+        """Textual recommendation for remediation."""
+        return self._data.get('Remediation', {}).get('Recommendation', {}).get('Text')
+
+    @property
+    def remediation_recommendation_url(self):
+        """URL for more information on the remediation."""
+        return self._data.get('Remediation', {}).get('Recommendation', {}).get('Url')
+
+    @property
+    def standards_guide_arn(self):
+        """Arn of the compliance standard."""
+        return self._data.get('ProductFields', {}).get('StandardsGuideArn')
+
+    @property
+    def resources(self):
+        """A list of resource dicts."""
+        return self._data.get('Resources', [{}])
+
     @property
     def resource_types(self):
         """Resource type."""
@@ -292,6 +317,11 @@ class Finding:  # pylint: disable=too-many-public-methods
         """Workflow status."""
         return self._data.get('Workflow', {}).get('Status')
 
+    @property
+    def record_state(self):
+        """Record status."""
+        return self._data.get('RecordState')
+
     @property
     def compliance_status(self):
         """Compliance status."""
